@@ -24,7 +24,12 @@ for (i in 1:AnzVariablen)  {
   AlleNans[i]=sum(!is.finite(Data[,i]))
 } # for (i=1:AnzVariablen)   
 ListeV=list('topright',border='white',cex=0.9,bty = "n")
-barplot(AlleNans/nrow(Data)*100,horiz=TRUE,names.arg=Names[1:AnzVariablen],
+Percentual=AlleNans/nrow(Data)*100
+barplot(Percentual,horiz=TRUE,names.arg=Names[1:AnzVariablen],
 legend.text=Names[1:AnzVariablen],args.legend=ListeV,cex.names=0.7,space=0.5,
 border=NA,xlim=c(0,100),col=c('red','blue','green','black','grey'),xlab='NaN in percent %',main='Amount of missing data')
+AllNaN=cbind(AlleNans,Percentual)
+rownames(AllNaN)=Names
+
+return(invisible(AllNaN))
 }
\ No newline at end of file
